@@ -84,7 +84,7 @@
         stop("Non convenient yax")
     def.par <- par(no.readonly = TRUE)
     on.exit(par(def.par))
-    nf <- layout(matrix(c(1, 2, 3, 4, 4, 5, 4, 4, 6), 3, 3), 
+    layout(matrix(c(1, 2, 3, 4, 4, 5, 4, 4, 6), 3, 3), 
         respect = TRUE)
     par(mar = c(0.1, 0.1, 0.1, 0.1))
     # modif mail P. Giraudoux 25/10/2004
